@@ -42,7 +42,6 @@
 #include "graph3d.h"	/* for DGRID3D_* options */
 #include "getcolor.h"
 #include "voxelgrid.h"
-#include "multiplot.h"	/* for replay_multiplot() */
 
 /* gnuplot commands */
 
@@ -80,7 +79,7 @@ const struct gen_ftable command_ftbl[] =
     { "pwd", pwd_command },
     { "q$uit", exit_command },
     { "ref$resh", refresh_command },
-    { "remulti$plot", replay_multiplot },
+    { "remulti$plot", remultiplot_command },
     { "rep$lot", replot_command },
     { "reread", reread_command },
     { "res$et", reset_command },
@@ -166,6 +165,7 @@ const struct gen_table save_tbl[] =
     { "set", SAVE_SET },
     { "ter$minal", SAVE_TERMINAL },
     { "var$iables", SAVE_VARS },
+    { "change$s", SAVE_CHANGES },
     { NULL, SAVE_INVALID }
 };
 
@@ -744,6 +744,7 @@ const struct gen_table plotstyle_tbl[] =
     { "fillst$eps", FILLSTEPS },
     { "fs$teps", FSTEPS },
     { "his$teps", HISTEPS },
+    { "hs$teps", HSTEPS },
     { "vec$tors", VECTOR },
     { "arrow$s", ARROWS },
     { "fin$ancebars", FINANCEBARS },
